@@ -105,10 +105,11 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
     from isc_common.models.deleted_progresses import Deleted_progresses
     from isc_common.models.progresses import Progresses
 
-    if settings.LOCKS.locked('cleanProgresses'):
+    key = 'cleanProgresses'
+    if settings.LOCKS.locked(key):
         return
 
-    settings.LOCKS.acquire('cleanProgresses')
+    settings.LOCKS.acquire(key)
     try:
         if isinstance(id_progresses, str):
             _id_progresses = []
@@ -176,9 +177,9 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
             else:
                 Progresses.objects.filter().delete()
                 Deleted_progresses.objects.filter().delete()
-        settings.LOCKS.release('cleanProgresses')
+        settings.LOCKS.release(key)
     except:
-        settings.LOCKS.release('cleanProgresses')
+        settings.LOCKS.release(key)
 
 
 class Stack:
