@@ -11,8 +11,9 @@ logger = logging.getLogger(__name__)
 
 
 def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None) -> Text:
+    key=f'create_tmp_mat_view_{mat_view_name}'
     if mat_view_name != None:
-        settings.LOCKS.acquire(f'create_tmp_mat_view_{mat_view_name}')
+        settings.LOCKS.acquire(key)
     else:
         mat_view_name = f'tmp_{str(uuid.uuid4()).replace("-", "_")}'
 
@@ -26,20 +27,21 @@ def create_tmp_mat_view(sql_str, params=[], indexes=[], mat_view_name=None) -> T
             cursor.execute(sql_txt, params)
             logger.debug(f'Created: {mat_view_name}')
         if mat_view_name != None:
-            settings.LOCKS.release(f'create_tmp_mat_view_{mat_view_name}')
+            settings.LOCKS.release(key)
         return mat_view_name
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
         if mat_view_name != None:
-            settings.LOCKS.release(f'create_tmp_mat_view_{mat_view_name}')
+            settings.LOCKS.release(key)
         return None
 
 
 def create_view(sql_str, params=[], view_name=None) -> None:
     if view_name == None:
         raise Exception(f'View must have name/')
-    settings.LOCKS.acquire(f'createt_view_{view_name}')
+    key=f'createt_view_{view_name}'
+    settings.LOCKS.acquire(key)
 
     sql_txt = f'''DROP VIEW IF EXISTS {view_name} CASCADE;'''
     sql_txt += f'''CREATE VIEW {view_name} AS {sql_str};'''
@@ -48,17 +50,18 @@ def create_view(sql_str, params=[], view_name=None) -> None:
             logger.debug(f'Creating: {view_name}')
             cursor.execute(sql_txt, params)
             logger.debug(f'Created: {view_name}')
-        settings.LOCKS.release(f'createt_view_{view_name}')
+        settings.LOCKS.release(key)
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        settings.LOCKS.release(f'createt_view_{view_name}')
+        settings.LOCKS.release(key)
 
 
 def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', params=[], indexes=[], unique_indexes=[], table_name=None, drop=True) -> None:
     if table_name == None:
         raise Exception(f'Table must have name/')
-    settings.LOCKS.acquire(f'create_tmp_table{table_name}')
+    key=f'create_tmp_table{table_name}'
+    settings.LOCKS.acquire(key)
 
     indexes_str = ''
     if isinstance(indexes, list):
@@ -90,46 +93,48 @@ def create_tmp_table(fields_str=None, sql_str=None, on_commit='delete rows', par
             logger.debug(f'Creating: {table_name}')
             cursor.execute(sql_txt, params)
             logger.debug(f'Created: {table_name}')
-        settings.LOCKS.release(f'create_tmp_table{table_name}')
+        settings.LOCKS.release(key)
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        settings.LOCKS.release(f'create_tmp_table{table_name}')
+        settings.LOCKS.release(key)
 
 
 def drop_mat_view(mat_view_name) -> bool:
     sql_txt = f'DROP MATERIALIZED VIEW IF EXISTS {mat_view_name} CASCADE;'
     try:
-        settings.LOCKS.acquire(f'drop_mat_view_{mat_view_name}')
+        key=f'drop_mat_view_{mat_view_name}'
+        settings.LOCKS.acquire(key)
         with connection.cursor() as cursor:
             logger.debug(f'Droping: {mat_view_name}')
             cursor.execute(sql_txt)
-        settings.LOCKS.release(f'drop_mat_view_{mat_view_name}')
+        settings.LOCKS.release(key)
         logger.debug(f'Droped: {mat_view_name}')
         return True
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        settings.LOCKS.release(f'drop_mat_view_{mat_view_name}')
+        settings.LOCKS.release(key)
         return False
 
 
 def refresh_mat_view(mat_view_name, progressStack=None):
     sql_txt = f'REFRESH MATERIALIZED VIEW {mat_view_name};'
-    settings.LOCKS.acquire(f'refresh_mat_view_{mat_view_name}')
+    key=f'refresh_mat_view_{mat_view_name}'
+    settings.LOCKS.acquire(key)
     try:
         with connection.cursor() as cursor:
             if progressStack != None:
                 progressStack.setContentsLabel(blinkString(f'Обновление материализованного преставления {mat_view_name}', bold=True))
             cursor.execute(sql_txt)
-        settings.LOCKS.release(f'refresh_mat_view_{mat_view_name}')
+        settings.LOCKS.release(key)
         if progressStack != None:
             progressStack.close()
         return True
     except Exception as ex:
         exc_info = sys.exc_info()
         logger.error(msg=ex, exc_info=exc_info)
-        settings.LOCKS.release(f'refresh_mat_view_{mat_view_name}')
+        settings.LOCKS.release(key)
         if progressStack != None:
             progressStack.close()
         return False
