@@ -15,6 +15,32 @@ def DateTimeToStr(date, mask='%d.%m.%Y %H:%M:%S', hours=0):
         date = StrToDate(date)
     return datetime.datetime.strftime(date + datetime.timedelta(hours=hours), mask)
 
+def manth_name(month):
+    if month == '01':
+        return 'Январь'
+    if month == '02':
+        return 'Февраль'
+    if month == '03':
+        return 'Март'
+    if month == '04':
+        return 'Апрель'
+    if month == '05':
+        return 'Май'
+    if month == '06':
+        return 'Июнь'
+    if month == '07':
+        return 'Июль'
+    if month == '08':
+        return 'Август'
+    if month == '09':
+        return 'Сентябрь'
+    if month == '10':
+        return 'Октябрь'
+    if month == '11':
+        return 'Ноябрь'
+    if month == '12':
+        return 'Декабрь'
+
 
 # Format Code List
 # The table below shows all the format codes that you can use.
