@@ -19,102 +19,118 @@ from isc_common.http.response import JsonResponse
 logger = logging.getLogger(__name__)
 
 
+class Exception_WS_Enabled(Exception):
+    pass
+
+
 def JsonWSResponseWithException(printing=False, printing_res=False):
-    class JE:
-        def __init__(self, func):
-            self.func = func
-            self.pp = pprint.PrettyPrinter(indent=4)
+    try:
+        class JE:
+            def __init__(self, func):
+                self.func = func
+                self.pp = pprint.PrettyPrinter(indent=4)
 
-        def print(self, o, str=None):
-            if str:
-                print(f"=========== Begin {str} ========================")
-            else:
-                print(f"=========== Begin {o.__class__.__name__} ========================")
-            if isinstance(o, dict):
-                self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
-            elif isinstance(o, object):
-                self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
+            def print(self, o, str=None):
+                if str:
+                    print(f"=========== Begin {str} ========================")
+                else:
+                    print(f"=========== Begin {o.__class__.__name__} ========================")
+                if isinstance(o, dict):
+                    self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
+                elif isinstance(o, object):
+                    self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
 
-            if str:
-                print(f"=========== End   {str} ========================")
-            else:
-                print(f"=========== End   {o.__class__.__name__} ========================")
-            print("\n")
+                if str:
+                    print(f"=========== End   {str} ========================")
+                else:
+                    print(f"=========== End   {o.__class__.__name__} ========================")
+                print("\n")
 
-        def __call__(self, *args, **kwargs):
-            request = args[0]
+            def __call__(self, *args, **kwargs):
+                request = args[0]
 
-            self.port = request.GET.get('ws_port')
-            if not self.port:
-                self.port = request.GET.get('port')
+                self.port = request.GET.get('ws_port')
                 if not self.port:
-                    self.port = request.session._session.get('ws_port')
+                    self.port = request.GET.get('port')
                     if not self.port:
-                        self.port = settings.WS_PORT
+                        self.port = request.session._session.get('ws_port')
                         if not self.port:
-                            raise Exception(Common.arraund_error('Do not have ws_port'))
+                            self.port = settings.WS_PORT
+                            if not self.port:
+                                raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_port'))
 
-            self.host = request.GET.get('ws_host')
-            if not self.host:
-                self.host = request.GET.get('host')
+                self.host = request.GET.get('ws_host')
                 if not self.host:
-                    self.host = request.session._session.get('host')
+                    self.host = request.GET.get('host')
                     if not self.host:
-                        self.host = settings.WS_HOST
+                        self.host = request.session._session.get('host')
                         if not self.host:
-                            raise Exception(Common.arraund_error('Do not have ws_host'))
+                            self.host = settings.WS_HOST
+                            if not self.host:
+                                raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_host'))
 
-            self.channel = request.GET.get('ws_channel')
-            if not self.channel:
-                self.channel = request.session._session.get('ws_channel')
+                self.channel = request.GET.get('ws_channel')
                 if not self.channel:
-                    raise Exception(Common.arraund_error('Do not have ws_channel'))
-
-            try:
-                if printing:
-                    _request = DSRequest(request)
-                    self.print(_request)
-                    self.print(request.COOKIES, 'request.COOKIES')
-                    self.print(request.GET, 'request.GET')
-                    self.print(request.POST, 'request.POST')
-                    self.print(request.META, 'request.META')
-
-                res = self.func(*args, **kwargs)
-                if printing_res:
-                    self.print(res)
-
-                return res
-            except Exception as ex:
-                exc_info = sys.exc_info()
-                stackTrace = traceback.format_exception(*exc_info)
-                message = str(ex)
+                    self.channel = request.session._session.get('ws_channel')
+                    if not self.channel:
+                        body = request.body.decode('utf8').replace("'", '"')
+                        body = json.loads(body)
+                        if settings.WS_CHANNEL != None and body.get('login') != None:
+                            self.channel = f'''{settings.WS_CHANNEL}_{body.get('login')}'''
+                        else:
+                            raise Exception_WS_Enabled(Common.arraund_error('Do not have ws_channel'))
 
                 try:
-                    ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
-                    ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
-                    ws.close()
+                    if printing:
+                        _request = DSRequest(request)
+                        self.print(_request)
+                        self.print(request.COOKIES, 'request.COOKIES')
+                        self.print(request.GET, 'request.GET')
+                        self.print(request.POST, 'request.POST')
+                        self.print(request.META, 'request.META')
+
+                    res = self.func(*args, **kwargs)
+                    if printing_res:
+                        self.print(res)
+
+                    return res
                 except Exception as ex:
-
                     exc_info = sys.exc_info()
-                    message = str(ex)
                     stackTrace = traceback.format_exception(*exc_info)
+                    message = str(ex)
 
-                    logging.error(message)
+                    try:
+                        ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
+                        ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
+                        ws.close()
+                    except Exception as ex:
+
+                        exc_info = sys.exc_info()
+                        message = str(ex)
+                        stackTrace = traceback.format_exception(*exc_info)
+
+                        logging.error(message)
+
+                        for x in stackTrace:
+                            logger.error(x)
+
+                        del exc_info
 
                     for x in stackTrace:
                         logger.error(x)
 
-                    del exc_info
+                    return JsonResponse(DSResponseOk().response)
 
-                for x in stackTrace:
-                    logger.error(x)
-
-                return JsonResponse(DSResponseOk().response)
-
-    return JE
+        return JE
+    except Exception_WS_Enabled:
+        return JsonResponseWithExceptionOld(printing=printing, printing_res=printing_res)
 
 
 def JsonResponseWithException(printing=False, printing_res=False):
+    return JsonWSResponseWithException(printing=printing, printing_res=printing_res)
+
+
+def JsonResponseWithExceptionOld(printing=False, printing_res=False):
     class JE:
         def __init__(self, func):
             self.func = func
@@ -166,91 +182,90 @@ def JsonResponseWithException(printing=False, printing_res=False):
 
 
 def JsonWSPostResponseWithException(printing=False, printing_res=False):
-    return JsonResponseWithException(printing=printing, printing_res=printing_res)
-    # class JE:
-    #     def __init__(self, func):
-    #         self.func = func
-    #         self.pp = pprint.PrettyPrinter(indent=4)
-    #
-    #     def print(self, o, str=None):
-    #         if str:
-    #             print(f"=========== Begin {str} ========================")
-    #         else:
-    #             print(f"=========== Begin {o.__class__.__name__} ========================")
-    #         if isinstance(o, dict):
-    #             self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
-    #         elif isinstance(o, object):
-    #             self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
-    #
-    #         if str:
-    #             print(f"=========== End   {str} ========================")
-    #         else:
-    #             print(f"=========== End   {o.__class__.__name__} ========================")
-    #         print("\n")
-    #
-    #     def __call__(self, *args, **kwargs):
-    #         request = args[0]
-    #
-    #         self.port = request.POST.get('ws_port')
-    #         if not self.port:
-    #             self.port = request.session._session.get('ws_port')
-    #             if not self.port:
-    #                 raise Exception(Common.arraund_error('Do not have ws_port'))
-    #
-    #         self.host = request.POST.get('ws_host')
-    #         if not self.host:
-    #             self.host = request.session._session.get('host')
-    #             if not self.host:
-    #                 raise Exception(Common.arraund_error('Do not have ws_host'))
-    #
-    #         self.channel = request.POST.get('ws_channel')
-    #         if not self.channel:
-    #             self.channel = request.session._session.get('ws_channel')
-    #             if not self.channel:
-    #                 raise Exception(Common.arraund_error('Do not have ws_channel'))
-    #
-    #         try:
-    #             if printing:
-    #                 _request = DSRequest(request)
-    #                 self.print(_request)
-    #                 self.print(request.COOKIES, 'request.COOKIES')
-    #                 self.print(request.GET, 'request.GET')
-    #                 self.print(request.POST, 'request.POST')
-    #                 self.print(request.META, 'request.META')
-    #
-    #             res = self.func(*args, **kwargs)
-    #             if printing_res:
-    #                 self.print(res)
-    #
-    #             return res
-    #         except Exception as ex:
-    #             exc_info = sys.exc_info()
-    #             stackTrace = traceback.format_exception(*exc_info)
-    #             message = str(ex)
-    #
-    #             try:
-    #                 ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
-    #                 ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
-    #                 ws.close()
-    #             except Exception as ex:
-    #
-    #                 exc_info = sys.exc_info()
-    #                 message = str(ex)
-    #                 stackTrace = traceback.format_exception(*exc_info)
-    #
-    #                 logging.error(message)
-    #
-    #                 for x in stackTrace:
-    #                     logger.error(x)
-    #
-    #                 del exc_info
-    #
-    #             for x in stackTrace:
-    #                 logger.error(x)
-    #
-    #             return JsonResponse(DSResponseOk().response)
-    #
-    # return JE
+    class JE:
+        def __init__(self, func):
+            self.func = func
+            self.pp = pprint.PrettyPrinter(indent=4)
+
+        def print(self, o, str=None):
+            if str:
+                print(f"=========== Begin {str} ========================")
+            else:
+                print(f"=========== Begin {o.__class__.__name__} ========================")
+            if isinstance(o, dict):
+                self.pp.pprint(RequestData(o).getDataWithOutField(['pp', '_state']).dict())
+            elif isinstance(o, object):
+                self.pp.pprint(RequestData(o.__dict__).getDataWithOutField(['pp', '_state']).dict())
+
+            if str:
+                print(f"=========== End   {str} ========================")
+            else:
+                print(f"=========== End   {o.__class__.__name__} ========================")
+            print("\n")
+
+        def __call__(self, *args, **kwargs):
+            request = args[0]
+
+            self.port = request.POST.get('ws_port')
+            if not self.port:
+                self.port = request.session._session.get('ws_port')
+                if not self.port:
+                    raise Exception(Common.arraund_error('Do not have ws_port'))
+
+            self.host = request.POST.get('ws_host')
+            if not self.host:
+                self.host = request.session._session.get('host')
+                if not self.host:
+                    raise Exception(Common.arraund_error('Do not have ws_host'))
+
+            self.channel = request.POST.get('ws_channel')
+            if not self.channel:
+                self.channel = request.session._session.get('ws_channel')
+                if not self.channel:
+                    raise Exception(Common.arraund_error('Do not have ws_channel'))
+
+            try:
+                if printing:
+                    _request = DSRequest(request)
+                    self.print(_request)
+                    self.print(request.COOKIES, 'request.COOKIES')
+                    self.print(request.GET, 'request.GET')
+                    self.print(request.POST, 'request.POST')
+                    self.print(request.META, 'request.META')
+
+                res = self.func(*args, **kwargs)
+                if printing_res:
+                    self.print(res)
+
+                return res
+            except Exception as ex:
+                exc_info = sys.exc_info()
+                stackTrace = traceback.format_exception(*exc_info)
+                message = str(ex)
+
+                try:
+                    ws = create_connection(f"ws://{self.host}:{self.port}/ws/{self.channel}/")
+                    ws.send(json.dumps(dict(message=message, stackTrace=stackTrace, type="error")))
+                    ws.close()
+                except Exception as ex:
+
+                    exc_info = sys.exc_info()
+                    message = str(ex)
+                    stackTrace = traceback.format_exception(*exc_info)
+
+                    logging.error(message)
+
+                    for x in stackTrace:
+                        logger.error(x)
+
+                    del exc_info
+
+                for x in stackTrace:
+                    logger.error(x)
+
+                return JsonResponse(DSResponseOk().response)
+
+    return JE
 
 
 class DSResponse(RPCResponse):
