@@ -23,9 +23,12 @@ class BaseRefQuerySet(AuditQuerySet):
             return super().filter(*args, **kwargs)
         else:
             full_name = kwargs.get('full_name')
-            res = self.get_full_name_id(None, full_name[1:])
-            delAttr(kwargs, 'full_name')
-            kwargs.setdefault('pk', res.pk)
+            if full_name != None:
+                res = self.get_full_name_id(None, full_name[1:])
+                delAttr(kwargs, 'full_name')
+                kwargs.setdefault('pk', res.pk)
+            else:
+                kwargs.setdefault('pk', 0)
             return super().filter(*args, **kwargs)
 
     def get_full_name_id(self, parent_id, name):
